@@ -1,13 +1,9 @@
 #!/usr/bin/perl
-# DocumentId:	$Id: debarchiver.pl 2505 2007-10-09 20:49:22Z ola $
-# Author:	$Author: ola $
-# Date:		$Date: 2007-10-09 22:49:22 +0200 (tis, 09 okt 2007) $
-# Version:	$Revision: 1.49 $
-# Summary:
+#
 #	This program reads a config file, traverse through all .changes files
 #	in the specified directory and puts the files into the right place.
 #
-#    Copyright (C) 2000-2007 Ola Lundqvist <opal@debian.org>
+#    Copyright (C) 2000-2008 Ola Lundqvist <ola@inguza.com>
 #    Copyright (C) 2007      Turbo Fredriksson <turbo@bayour.com>
 #    Copyright (C) 2004-2005 Russ Allbery <rra@stanford.edu>
 #    Copyright (C) 2005      Joel Baker <lucifer@lightbearer.com>
@@ -51,17 +47,17 @@ use OpaL::read qw(readfile readcommand);
 ########################### CONSTANTS #########################################
 ###############################################################################
 # Changelog:
-#  2000-2004 Ola Lundqvist <opal@debian.org>
+#  2000-2004 Ola Lundqvist <ola@inguza.com>
 #	Written
-#  2005-05-01 Ola Lundqvist <opal@debian.org>
+#  2005-05-01 Ola Lundqvist <ola@inguza.com>
 #	Bug fix for bzip2 support.
 #  2005-05-06 Daniel Leidert <daniel.leidert@wgdd.de>
 #       Add setting to enable/disable signature checking in distinput-dirs.
-#  2005-09-09 Ola Lundqvist <opal@debian.org>
+#  2005-09-09 Ola Lundqvist <ola@inguza.com>
 #       Support for gpg password file.
 #  2005-09-15 Daniel Leidert <daniel.leidert.spam@gmx.net>
 #       Fix regarding $gpgpassfile.
-#  2005-10-08 Ola Lundqvist <opal@debian.org>
+#  2005-10-08 Ola Lundqvist <ola@inguza.com>
 #	Now invokes a helper program to sign the files. It may be implemented
 #	by some perl module but this solution was good enough.
 #  2005-10-11 Daniel Leidert <daniel.leidert@wgdd.de>
@@ -73,7 +69,7 @@ use OpaL::read qw(readfile readcommand);
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
 #       Allow forcing an install of an upload (i.e., ignore existing files in
 #       destdir).
-#  2007-10-09 Ola Lundqvist <opal@debian.org>
+#  2007-10-09 Ola Lundqvist <ola@inguza.com>
 #       Changed force option to ignoredestcheck option.
 
 $copycmd = "cp -af";
@@ -98,11 +94,11 @@ $gpgpassfile = "$ENV{HOME}/.gnupg/passphrase";
 ########################## DECLARATION ########################################
 ###############################################################################
 # Changelog:
-#  2000-2004 Ola Lundqvist <opal@debian.org>
+#  2000-2004 Ola Lundqvist <ola@inguza.com>
 #	Written
-#  2007-10-08 Ola Lundqvist <opal@debian.org>
+#  2007-10-08 Ola Lundqvist <ola@inguza.com>
 #       Updated with new options.
-#  2007-10-09 Ola Lundqvist <opal@debian.org>
+#  2007-10-09 Ola Lundqvist <ola@inguza.com>
 #       Changed force option to ignoredestcheck option.
 
 # Indexed by config name.
@@ -161,9 +157,9 @@ $ignoredestcheck = 0;
 ############################# ARGS ############################################
 ###############################################################################
 # Changelog:
-#  2000-2004 Ola Lundqvist <opal@debian.org>
+#  2000-2004 Ola Lundqvist <ola@inguza.com>
 #	Written
-#  2005-10-08 Ola Lundqvist <opal@debian.org>
+#  2005-10-08 Ola Lundqvist <ola@inguza.com>
 #	Added the possibility to specify a config file on command line.
 #	Inspired by a patch from Alexander Wirt <formorer@debian.org>.
 
@@ -209,12 +205,12 @@ while ($_ = shift @ARGS1) {
 ############################ CONFIG ###########################################
 ###############################################################################
 # Changelog:
-#  2000-2004 Ola Lundqvist <opal@debian.org>
+#  2000-2004 Ola Lundqvist <ola@inguza.com>
 #	Written
-#  2005-10-08 Ola Lundqvist <opal@debian.org>
+#  2005-10-08 Ola Lundqvist <ola@inguza.com>
 #	Added the possibility to specify a config file on command line.
 #	Inspired by a patch from Alexander Wirt <formorer@debian.org>.
-#  2007-08-14 Ola Lundqvist <opal@debian.org>
+#  2007-08-14 Ola Lundqvist <ola@inguza.com>
 #       Changed severity level for configuration file problems from info
 #       to warning, so that it is displayed in the normal case.
 
@@ -243,9 +239,9 @@ if (-e $cmdlineconfigfile) {
 ######################### INPUT CONFIG ########################################
 ###############################################################################
 # Changelog:
-#  2000-2004 Ola Lundqvist <opal@debian.org>
+#  2000-2004 Ola Lundqvist <ola@inguza.com>
 #	Written
-#  2007-08-14 Ola Lundqvist <opal@debian.org>
+#  2007-08-14 Ola Lundqvist <ola@inguza.com>
 #       Changed severity level for configuration file problems from info
 #       to warning, so that it is displayed in the normal case.
 
@@ -277,11 +273,11 @@ else {
 ############################# HELP ############################################
 ###############################################################################
 # Changelog:
-#  2000-2004 Ola Lundqvist <opal@debian.org>
+#  2000-2004 Ola Lundqvist <ola@inguza.com>
 #	Written
-#  2005-09-09 Ola Lundqvist <opal@debian.org>
+#  2005-09-09 Ola Lundqvist <ola@inguza.com>
 #       Added information about gpg support.
-#  2005-10-08 Ola Lundqvist <opal@debian.org>
+#  2005-10-08 Ola Lundqvist <ola@inguza.com>
 #	Added the possibility to specify a config file on command line.
 #	Inspired by a patch from Alexander Wirt <formorer@debian.org>.
 #	Now invokes a helper program to sign the files. It may be implemented
@@ -289,16 +285,16 @@ else {
 #  2005-10-14 Daniel Leidert <daniel.leidert@wgdd.de>
 #	Removed signcmd.
 #  2006-02-25 Yaroslav Halchenko <debian@onerussian.com> and
-#             Ola Lundqvist <opal@debian.org>
+#             Ola Lundqvist <ola@inguza.com>
 #       Default major section function.
-#  2006-11-28 Ola Lundqvist <opal@debian.org>
+#  2006-11-28 Ola Lundqvist <ola@inguza.com>
 #       Sorted options in alphabetical order.
-#  2007-10-08 Ola Lundqvist <opal@debian.org>
+#  2007-10-08 Ola Lundqvist <ola@inguza.com>
 #       Make it possible to specify mail sender.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
 #       Allow forcing an install of an upload (i.e., ignore existing files in
 #       destdir).
-#  2007-10-09 Ola Lundqvist <opal@debian.org>
+#  2007-10-09 Ola Lundqvist <ola@inguza.com>
 #       Changed force option to ignoredestcheck option.
 
 $version = "0.8.0";
@@ -415,19 +411,19 @@ will be parsed. Here you can change the following variables
 ############################# ARGS ############################################
 ###############################################################################
 # Changelog:
-#  2000-2004 Ola Lundqvist <opal@debian.org>
+#  2000-2004 Ola Lundqvist <ola@inguza.com>
 #	Written
 #  2005-05-01 Daniel Leidert <daniel.leidert.spam@gmx.net>
 #	Added bzip2 support.
-#  2005-09-09 Ola Lundqvist <opal@debian.org>
+#  2005-09-09 Ola Lundqvist <ola@inguza.com>
 #       Added options for gpg signing support.
 #  2006-02-25 Yaroslav Halchenko <debian@onerussian.com> and
-#             Ola Lundqvist <opal@debian.org>
+#             Ola Lundqvist <ola@inguza.com>
 #       Default major section function.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
 #       Allow forcing an install of an upload (i.e., ignore existing files in
 #       destdir).
-#  2007-10-09 Ola Lundqvist <opal@debian.org>
+#  2007-10-09 Ola Lundqvist <ola@inguza.com>
 #       Changed force option to ignoredestcheck option.
 
 while ($_ = shift @ARGS2) {
@@ -601,7 +597,7 @@ if (defined $indexall) {
 #		including the .gz file.
 # Arguments:	directory, filename
 # Changelog:
-#  2001-07-14 Ola Lundqvist <opal@debian.org>
+#  2001-07-14 Ola Lundqvist <ola@inguza.com>
 #	Written.
 ###############################################################################
 
@@ -630,9 +626,9 @@ sub createPF($$) {
 # Arguments:	directory, distribution, section, architecture
 # Uses:         %release
 # Changelog:
-#  2004-08-09 Ola Lundqvist <opal@debian.org>
+#  2004-08-09 Ola Lundqvist <ola@inguza.com>
 #	Written.
-#  2004-08-10 Ola Lundqvist <opal@debian.org>
+#  2004-08-10 Ola Lundqvist <ola@inguza.com>
 #	Renamed $release to $contents. Don't generate if any under a symlink.
 ###############################################################################
 
@@ -690,15 +686,15 @@ sub createRelease($$$$) {
 # Description:	Determine the address to set mail to.
 # Uses:		%CConf, %CMeta hash.
 # Changelog:
-#  2003-02-12	Ola Lundqvist <opal@debian.org>
+#  2003-02-12	Ola Lundqvist <ola@inguza.com>
 #	Wrote it.
-#  2003-02-13	Ola Lundqvist <opal@debian.org>
+#  2003-02-13	Ola Lundqvist <ola@inguza.com>
 #	Extended it with @hostname calculation.
-#  2003-02-28 Ola Lundqvist <opal@debian.org>
+#  2003-02-28 Ola Lundqvist <ola@inguza.com>
 #	Added debugging information.
-#  2003-03-14 Ola Lundqvist <opal@debian.org>
+#  2003-03-14 Ola Lundqvist <ola@inguza.com>
 #	Switched to using CMeta for ChangeLog meta information.
-#  2003-06-10 Ola Lundqvist <opal@debian.org>
+#  2003-06-10 Ola Lundqvist <ola@inguza.com>
 #	Switched from direct determination of changes owner to use
 #	precalculated data from CMeta{FileOwner}.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
@@ -735,15 +731,15 @@ sub determineMailTo() {
 # Description:	Send an email to persons, for package with message.
 # Arguments:	to, package, key, message
 # Changelog:
-#  2002-09-11 Ola Lundqvist <opal@debian.org>
+#  2002-09-11 Ola Lundqvist <ola@inguza.com>
 #	Stub written.
-#  2003-02-12 Ola Lundqvist <opal@debian.org>
+#  2003-02-12 Ola Lundqvist <ola@inguza.com>
 #	Writen the mail sending function.
-#  2003-02-28 Ola Lundqvist <opal@debian.org>
+#  2003-02-28 Ola Lundqvist <ola@inguza.com>
 #	Added debugging information and fixed arg handling.
-#  2003-03-13 Ola Lundqvist <opal@debian.org>
+#  2003-03-13 Ola Lundqvist <ola@inguza.com>
 #	Debugged the mail command. It stalls.
-#  2007-10-08 Ola Lundqvist <opal@debian.org>
+#  2007-10-08 Ola Lundqvist <ola@inguza.com>
 #       Make it possible to specify mail sender.
 ###############################################################################
 
@@ -784,11 +780,11 @@ sub email($$$$) {
 #		including the .gz file.
 # Uses:		%CMeta and maybe %Cfiles in the future.
 # Changelog:
-#  2002-09-11	Ola Lundqvist <opal@debian.org>
+#  2002-09-11	Ola Lundqvist <ola@inguza.com>
 #	Written.
-#  2003-02-12	Ola Lundqvist <opal@debian.org>
+#  2003-02-12	Ola Lundqvist <ola@inguza.com>
 #	Uses CConf instead of cfile argument.
-#  2003-03-14 Ola Lundqvist <opal@debian.org>
+#  2003-03-14 Ola Lundqvist <ola@inguza.com>
 #	Switched to using CMeta for ChangeLog meta information.
 ###############################################################################
 
@@ -806,11 +802,11 @@ sub mailSuccess() {
 # Name:		mailReject
 # Uses:		%CMeta and maybe %Cfiles in the future.
 # Changelog:
-#  2002-09-12	Ola Lundqvist <opal@debian.org>
+#  2002-09-12	Ola Lundqvist <ola@inguza.com>
 #	Written using data from mailSuccess.
-#  2003-02-12	Ola Lundqvist <opal@debian.org>
+#  2003-02-12	Ola Lundqvist <ola@inguza.com>
 #	Uses CConf instead of cfile argument.
-#  2003-03-14   Ola Lundqvist <opal@debian.org>
+#  2003-03-14   Ola Lundqvist <ola@inguza.com>
 #	Switched to using CMeta for ChangeLog meta information.
 #  2007-10-08   Turbo Fredriksson <turbo@bayour.com>
 #       Error string in beginning and full message (+= => .=).
@@ -841,7 +837,7 @@ sub mailReject() {
 # Changes:	%dests
 # Uses:		@distributions, @sections, @architectures, $destdir.
 # Changelog:
-#  2001-07-23 Ola Lundqvist <opal@debian.org>
+#  2001-07-23 Ola Lundqvist <ola@inguza.com>
 #	Written.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
 #       Change in foreach to use my variable.
@@ -870,19 +866,19 @@ sub handleScanAll() {
 #		$autoscanpackages, $autoscansources.
 # Changes:	$ENV{PWD}
 # Changelog:
-#  2001-06-26 Ola Lundqvist <opal@debian.org>
+#  2001-06-26 Ola Lundqvist <ola@inguza.com>
 #	Written.
-#  2001-07-23 Ola Lundqvist <opal@debian.org>
+#  2001-07-23 Ola Lundqvist <ola@inguza.com>
 #	Added lockfile check to distr directory.
 #	Improved documentation.
-#  2002-01-22 Ola Lundqvist <opal@debian.org>
+#  2002-01-22 Ola Lundqvist <ola@inguza.com>
 #	Moved lock file checking to its own function.
-#  2003-02-12 Ola Lundqvist <opal@debian.org>
+#  2003-02-12 Ola Lundqvist <ola@inguza.com>
 #	Now redirects stderr to stdout for
 #	dpkg-scan* so that it can be logged.
 #  2005-05-01 Daniel Leidert <daniel.leidert.spam@gmx.net>
 #	Modified to add bzip2 support.
-#  2005-05-02 Ola Lundqvist <opal@debian.org>
+#  2005-05-02 Ola Lundqvist <ola@inguza.com>
 #	Bugfix for bzip2 support.
 ###############################################################################
 
@@ -985,7 +981,7 @@ sub handleScan() {
 #               reference to section array to fill out,
 #               reference to architectures array to fill out
 # Changelog:
-#  2004-08-10 Ola Lundqvist <opal@debian.org>
+#  2004-08-10 Ola Lundqvist <ola@inguza.com>
 #      Written.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
 #       Change in foreach to use my variable.
@@ -1020,11 +1016,11 @@ sub findSectionsArchitectures($\@\@) {
 # Uses:		%dests, $destdir, $cachedir
 # Returns:      Path to the generated config file
 # Changelog:
-#  2004-08-10 Ola Lundqvist <opal@debian.org>
+#  2004-08-10 Ola Lundqvist <ola@inguza.com>
 #	Written.
 #  2005-05-01 Daniel Leidert <daniel.leidert.spam@gmx.net>
 #	Modified to add bzip2 support.
-#  2005-05-02 Ola Lundqvist <opal@debian.org>
+#  2005-05-02 Ola Lundqvist <ola@inguza.com>
 #	Bugfix for bzip2 support.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
 #       Change in foreach to use my variable.
@@ -1095,11 +1091,11 @@ sub generateIndexConfig() {
 #	Written.
 #  2005-09-02 Joergen Haegg <jorgen.hagg@axis.com>
 #       Unlink Relase.gpg before creation.
-#  2005-09-09 Ola Lundqvist <opal@debian.org>
+#  2005-09-09 Ola Lundqvist <ola@inguza.com>
 #	Made it possible for gnupg to read passphrase from file.
 #  2005-09-15 Daniel Leidert <daniel.leidert.spam@gmx.net>
 #	Fix regarding $gpgpassfile.
-#  2005-10-08 Ola Lundqvist <opal@debian.org>
+#  2005-10-08 Ola Lundqvist <ola@inguza.com>
 #	Now invokes a helper program to sign the files. It may be implemented
 #	by some perl module but this solution was good enough.
 #  2005-10-14 Daniel Leidert <daniel.leidert@wgdd.de>
@@ -1169,13 +1165,13 @@ sub generateRelease($$\@\@) {
 # Uses:		%dests, $destdir
 # Changes:	$ENV{PWD}
 # Changelog:
-#  2004-07-30 Ola Lundqvist <opal@debian.org>
+#  2004-07-30 Ola Lundqvist <ola@inguza.com>
 #	Written.
-#  2004-08-09 Ola Lundqvist <opal@debian.org>
+#  2004-08-09 Ola Lundqvist <ola@inguza.com>
 #	Add merging of binary-all Packages file.
 #  2005-05-01 Daniel Leidert <daniel.leidert.spam@gmx.net>
 #	Modified to add bzip2 support and handle contents-all in a proper way.
-#  2005-05-02 Ola Lundqvist <opal@debian.org>
+#  2005-05-02 Ola Lundqvist <ola@inguza.com>
 #	Bugfix for bzip2 support.
 #  2005-08-20 Russ Allbery <rra@stanford.edu>
 #       Call generateRelease for Release file support (optionally signed).
@@ -1268,7 +1264,7 @@ sub handleIndex() {
 # Description:	Sort packages into the right place.
 # Uses:		parseChangesFile, verifyChangesFile, handleChangesFile
 # Changelog:
-#  2005-05-01 Ola Lundqvist <opal@debian.org>
+#  2005-05-01 Ola Lundqvist <ola@inguza.com>
 #	Written using parts of handleSorting.
 #	Improved changes file verification structure.
 #  2005-05-06 Daniel Leidert <daniel.leidert@wgdd.de>
@@ -1325,13 +1321,13 @@ sub findAndSortChangesFiles($;$) {
 # Name:		handleSorting
 # Description:	Sort packages into the right place.
 # Changelog:
-#  2001-07-23 Ola Lundqvist <opal@debian.org>
+#  2001-07-23 Ola Lundqvist <ola@inguza.com>
 #	Moved from START section to this subprocedure.
 #  2005-04-xx Bob Proulx <bob@proulx.com>
 #	Added support for .changes files in distinputdir.
-#  2005-04-30 Ola Lundqvist <opal@debian.org>
+#  2005-04-30 Ola Lundqvist <ola@inguza.com>
 #	Modified support for .changes files in distinput dir.
-#  2005-05-01 Ola Lundqvist <opal@debian.org>
+#  2005-05-01 Ola Lundqvist <ola@inguza.com>
 #	Broke out .changes file handling to a separate function
 #	findAndSortChangesFiles.
 #  2005-05-06 Daniel Leidert <daniel.leidert@wgdd.de>
@@ -1383,9 +1379,9 @@ sub handleSorting() {
 # Description:	Fix the distribution directory structure.
 # Uses:		@distributions, @sections, @architectures, $fixstructure
 # Changelog:
-#  2001-07-23 Ola Lundqvist <opal@debian.org>
+#  2001-07-23 Ola Lundqvist <ola@inguza.com>
 #	Moved from START section to this subprocedure.
-#  2004-08-09 Ola Lundqvist <opal@debian.org>
+#  2004-08-09 Ola Lundqvist <ola@inguza.com>
 #	Call createRelease to build Release files.
 #  2007-10-08 Turbo Fredriksson <turbo@bayour.com>
 #       Distmapping for files.
@@ -1444,7 +1440,7 @@ sub handleStructureFix() {
 #		The distribution to install to.
 # Changes:	see parseKernelFile
 # Changelog:
-#  2001-06-29 Ola Lundqvist <opal@debian.org>
+#  2001-06-29 Ola Lundqvist <ola@inguza.com>
 #	Written.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
 #       Change in foreach to use my variable.
@@ -1475,7 +1471,7 @@ sub handleDebOnlyFile($$) {
 #	filepath     If file exist in dest dirs.
 #       ""           If file not found.
 # Changelog:
-#  2007-10-08 Ola Lundqvist <opal@debian.org>
+#  2007-10-08 Ola Lundqvist <ola@inguza.com>
 #       Write function based on the code from Turbo Fredriksson <turbo@bayour.com>
 #       in function verifyChangesFile below.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
@@ -1523,7 +1519,7 @@ sub checkFileInDestDirs($) {
 # Returns:
 #	MD5 sum for file
 # Changelog:
-#  2007-10-08 Ola Lundqvist <opal@debian.org>
+#  2007-10-08 Ola Lundqvist <ola@inguza.com>
 #       Write function based on the code from Turbo Fredriksson <turbo@bayour.com>
 #       in function verifyChangesFile below.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
@@ -1553,7 +1549,7 @@ sub getMD5HashForFile($) {
 # Changelog:
 #  2005-04-xx Bob Proulx <bob@proulx.com>
 #	Split out parts of handleChangesFile to this proc.
-#  2005-05-01 Ola Lundqvist <opal@debian.org>
+#  2005-05-01 Ola Lundqvist <ola@inguza.com>
 #	Renamed from parseChangesFile to verifyChangesFile and removed parse
 #	part. Rewrote parts to allow it to return some kind of status.
 #	Added code to verify that changes file upload is complete.
@@ -1562,13 +1558,13 @@ sub getMD5HashForFile($) {
 #       independetly.
 #  2007-10-08 Turbo Fredriksson <turbo@bayour.com>
 #       Stat only existing files.
-#  2007-10-08 Ola Lundqvist <opal@debian.org>
+#  2007-10-08 Ola Lundqvist <ola@inguza.com>
 #       Correct indention (as Turbo explained).
 #  2007-10-08 Turbo Fredriksson <turbo@bayour.com>
 #       The changes file is only incomplete if the file is missing _and_
 #       a file in the destination do not already exist with the correct MD5
 #       hash.
-#  2007-10-08 Ola Lundqvist <opal@debian.org>
+#  2007-10-08 Ola Lundqvist <ola@inguza.com>
 #       Extraced the file check to two own functions.
 #       Changed the order to always check for installed files and reject if it
 #       exist with wrong size or md5sum.
@@ -1577,7 +1573,7 @@ sub getMD5HashForFile($) {
 #       Check incomplete time only once.
 #       Allow forcing an install of an upload (i.e., ignore existing files in
 #       destdir).
-#  2007-10-09 Ola Lundqvist <opal@debian.org>
+#  2007-10-09 Ola Lundqvist <ola@inguza.com>
 #       Changed force option to ignoredestcheck option.
 ###############################################################################
 
@@ -1669,11 +1665,11 @@ sub verifyChangesFile($$) {
 # Arguments:	The .changes file.
 # Returns:	nothing
 # Changelog:
-#  2001-06-26 Ola Lundqvist <opal@debian.org>
+#  2001-06-26 Ola Lundqvist <ola@inguza.com>
 #	Taken from the main script. Cut and paste with simple changes.
-#  2003-03-13 Ola Lundqvist <opal@debian.org>
+#  2003-03-13 Ola Lundqvist <ola@inguza.com>
 #	Added mailSuccess command thing.
-#  2003-06-10 Ola Lundqvist <opal@debian.org>
+#  2003-06-10 Ola Lundqvist <ola@inguza.com>
 #	Now uses uploaderIsChangesFileOwner to make sure that the owner can be
 #	calculated before the changes file will be moved or something similar.
 #       Also added rejectChangesFile to vrfycmd so that messages will be sent
@@ -1701,7 +1697,7 @@ sub handleChangesFile($) {
 # Description:	Sets CMeta{FileOwner} from 
 # Changes:	CMeta
 # Changelog:
-#  2003-06-10 Ola Lundqvist <opal@debian.org
+#  2003-06-10 Ola Lundqvist <ola@inguza.com
 #	Wrote it.
 ###############################################################################
 
@@ -1724,20 +1720,20 @@ sub uploaderIsChangesFileOwner($) {
 # Description:	Reject the changes file so that it is moved away.
 # Uses:		%CFiles, %CConf
 # Changelog:
-#  2003-02-12 Ola Lundqvist <opal@debian.org
+#  2003-02-12 Ola Lundqvist <ola@inguza.com
 #	Wrote it.
-#  2003-02-28 Ola Lundqvist <opal@debian.org
+#  2003-02-28 Ola Lundqvist <ola@inguza.com
 #	Implemented the commands in the foreach loop.
-#  2003-03-14 Ola Lundqvist <opal@debian.org>
+#  2003-03-14 Ola Lundqvist <ola@inguza.com>
 #	Switched to using CMeta for ChangeLog meta information.
-#  2005-05-01 Ola Lundqvist <opal@debian.org>
+#  2005-05-01 Ola Lundqvist <ola@inguza.com>
 #	Modified reject cause.
 #  2005-05-06 Daniel Leidert <daniel.leidert@wgdd.de>
 #       Fixed move-command and check for .changes file.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
 #       Change in foreach to use my variable.
 #       Create reject log code.
-#  2007-10-09 Ola Lundqvist <opal@debian.org>
+#  2007-10-09 Ola Lundqvist <ola@inguza.com>
 #       Moved reject log code to REJECT dir and changed coding style some.
 ###############################################################################
 
@@ -1784,11 +1780,11 @@ sub rejectChangesFile() {
 # Arguments:	The package file (the key in %CFiles).
 # Returns:	nothing
 # Changelog:
-#  2001-06-26 Ola Lundqvist <opal@debian.org>
+#  2001-06-26 Ola Lundqvist <ola@inguza.com>
 #	Taken from the main script. Cut and paste with simple changes.
 #  2006-06-11 Michael Hanke <michael.hanke@gmail.com>
 #       Only remove source tarball file if not referenced by any other .changes file.
-#  2006-07-20 Ola Lundqvist <opal@debian.org>
+#  2006-07-20 Ola Lundqvist <ola@inguza.com>
 #       Changed indentation.
 #  2007-10-08 Turbo Fredriksson <turbo@bayour.com>
 #       Distmapping for files.
@@ -1912,9 +1908,9 @@ sub handlePackageFile ($) {
 #		if on the form foo/bar it returns (foo, bar) and if it
 #		is on the form foo it returns (main, foo).
 # Changelog:
-#  2001-06-10 Ola Lundqvist <opal@debian.org>
+#  2001-06-10 Ola Lundqvist <ola@inguza.com>
 #	Wrote it.
-#  2003-03-14 Ola Lundqvist <opal@debian.org>
+#  2003-03-14 Ola Lundqvist <ola@inguza.com>
 #	Now CConf{ChangesFile} is changed when copying it.
 #  2007-10-08 Turbo Fredriksson <turbo@bayour.com>
 #       Distmapping for files.
@@ -2019,7 +2015,7 @@ sub destinationError() {
 # Name:		createLockExit
 # Description:	creates a lockfile, but exits if it can't.
 # Changelog:
-#  2002-01-22 Ola Lundqvist <opal@debian.org>
+#  2002-01-22 Ola Lundqvist <ola@inguza.com>
 #	Written.
 # Arguments:   	$lockfile
 # Returns:	nothing
@@ -2042,7 +2038,7 @@ sub createLockExit($) {
 # Needs:	$rmcmd $lockfile
 # Returns:	nothing
 # Changelog:
-#  2002-01-22 Ola Lundqvist <opal@debian.org>
+#  2002-01-22 Ola Lundqvist <ola@inguza.com>
 #	Written.
 ###############################################################################
 
@@ -2058,7 +2054,7 @@ sub removeLockExit() {
 # Arguments:    $lockfile
 # Returns:	nothing
 # Changelog:
-#  2002-01-22 Ola Lundqvist <opal@debian.org>
+#  2002-01-22 Ola Lundqvist <ola@inguza.com>
 #	Written.
 ###############################################################################
 
@@ -2081,10 +2077,10 @@ sub removeLockfile() {
 #		if on the form foo/bar it returns (foo, bar) and if it
 #		is on the form foo it returns (main, foo).
 # Changelog:
-#  2001-06-10 Ola Lundqvist <opal@debian.org>
+#  2001-06-10 Ola Lundqvist <ola@inguza.com>
 #	Written.
 #  2006-02-25 Yaroslav Halchenko <debian@onerussian.com> and
-#             Ola Lundqvist <opal@debian.org>
+#             Ola Lundqvist <ola@inguza.com>
 #       Default major section function.
 ###############################################################################
 
@@ -2105,7 +2101,7 @@ sub parseSection($) {
 # Arguments:	The string.
 # Returns:	($hash, $size, $section, $prio)
 # Changelog:
-#  2001-06-10 Ola Lundqvist <opal@debian.org>
+#  2001-06-10 Ola Lundqvist <ola@inguza.com>
 #	Written.
 ###############################################################################
 
@@ -2119,7 +2115,7 @@ sub parseFileStruct($) {
 # Arguments:	deb filename.
 # Returns:	($pkgname, $version, $arch, $ext)
 # Changelog:
-#  2001-06-10 Ola Lundqvist <opal@debian.org>
+#  2001-06-10 Ola Lundqvist <ola@inguza.com>
 #	Written.
 ###############################################################################
 
@@ -2149,9 +2145,9 @@ sub parseFileName($) {
 # Arguments:	A deb file name.
 # Changes:	see parseChangesFile
 # Changelog:
-#  2001-06-29 Ola Lundqvist <opal@debian.org>
+#  2001-06-29 Ola Lundqvist <ola@inguza.com>
 #	Written with info from parseChanges.
-#  2003-02-12 Ola Lundqvist <opal@debian.org>
+#  2003-02-12 Ola Lundqvist <ola@inguza.com>
 #	Added ChangesFile to CConf hash.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
 #       Change in foreach to use my variable.
@@ -2238,17 +2234,17 @@ sub parseDebOnlyFile($$) {
 #	%CDesc
 #		$pkgname => "The short description of the package."
 # ChangeLog:
-#  2001-06-10 Ola Lundqvist <opal@debian.org>
+#  2001-06-10 Ola Lundqvist <ola@inguza.com>
 #  	Written.
-#  2001-06-26 Ola Lundqvist <opal@debian.org>
+#  2001-06-26 Ola Lundqvist <ola@inguza.com>
 #  	Changed print to pdebug.
-#  2002-09-11 Ola Lundqvist <opal@debian.org>
+#  2002-09-11 Ola Lundqvist <ola@inguza.com>
 #	Added uploaders field to the description.
-#  2003-02-12 Ola Lundqvist <opal@debian.org>
+#  2003-02-12 Ola Lundqvist <ola@inguza.com>
 #	Added ChangesFile to CConf hash.
-#  2003-03-14 Ola Lundqvist <opal@debian.org>
+#  2003-03-14 Ola Lundqvist <ola@inguza.com>
 #	Switched to using CMeta for ChangeLog meta information.
-#  2005-05-01 Ola Lundqvist <opal@debian.org>
+#  2005-05-01 Ola Lundqvist <ola@inguza.com>
 #	Renamed to parseChangesFile.
 #  2006-03-25 Jrmy Bobbio <jeremy.bobbio@etu.upmc.fr>
 #       One line fix for udeb support.
@@ -2333,7 +2329,7 @@ sub parseChangesFile($) {
 # Changes:	%Override	The override structure this overrides the
 #				packages information.
 # Changelog:
-#  2001-06-26 Ola Lundqvist <opal@debian.org>
+#  2001-06-26 Ola Lundqvist <ola@inguza.com>
 #	Written.
 #  2007-10-09 Turbo Fredriksson <turbo@bayour.com>
 #       Change in foreach to use my variable.
@@ -2372,7 +2368,7 @@ sub parseOverrideFile($$$) {
 #		path to give it against.
 # Returns:	($pkgname, $version, $arch, $ext)
 # Changelog:
-#  2001-06-26 Ola Lundqvist <opal@debian.org>
+#  2001-06-26 Ola Lundqvist <ola@inguza.com>
 #	Written.
 ##############################################################################
 
@@ -2395,7 +2391,7 @@ sub relativePath ($$) {
 # Arguments:	two arguments
 # Returns:	the second one if it is not empty, else the first one.
 # Changelog:
-#  2001-06-26 Ola Lundqvist <opal@debian.org>
+#  2001-06-26 Ola Lundqvist <ola@inguza.com>
 #	Written.
 ###############################################################################
 
@@ -2691,6 +2687,6 @@ B<apt-ftparchive>(1)
 
 =head1 AUTHOR
 
-Ola Lundqvist <opal@debian.org>
+Ola Lundqvist <ola@inguza.com>
 
 =cut
